#
# spec file for package nginx-1.0
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           nginx-1.0
Version:        1.0.15
Release:        1.19
#
%define pkg_name nginx
#
%define ngx_prefix     %{_prefix}
%define ngx_sbindir    %{_sbindir}/nginx
%define ngx_conf_dir   %{_sysconfdir}/nginx
%define ngx_conf_path  %{ngx_conf_dir}/nginx.conf
%define ngx_log_dir    /var/log/nginx
%define ngx_error_log  %{ngx_log_dir}/error.log
%define ngx_access_log %{ngx_log_dir}/access.log
%define ngx_pid_path   /var/run/nginx.pid
%define ngx_lock_path  /var/run/nginx.lock
%define ngx_home       /var/lib/nginx
%define ngx_tmp_http   %{ngx_home}/tmp/
%define ngx_tmp_proxy  %{ngx_home}/proxy/
%define ngx_tmp_fcgi   %{ngx_home}/fastcgi/
%define ngx_tmp_scgi   %{ngx_home}/scgi/
%define ngx_tmp_uwsgi  %{ngx_home}/uwsgi/
%define ngx_user_group nginx
%define with_cpp_test   0
%define with_google_perftools 0
%if 0%{?suse_version} >= 1110 && 0%{?sles_version} != 10 && 0%{?sles_version} != 11
%define with_passenger 1
%define with_libatomic 1
%endif
#
Group:          Productivity/Networking/Web/Proxy
License:        BSD-2-Clause
#
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?with_cpp_test}
BuildRequires:  gcc-c++
%endif
BuildRequires:  gd-devel
BuildRequires:  GeoIP-devel
%if 0%{?with_google_perftools}
BuildRequires:  google-perftools-devel
%endif
%if 0%{?with_libatomic}
BuildRequires:  libatomic-ops-devel
%endif
BuildRequires:  libxslt-devel
BuildRequires:  openssl-devel
BuildRequires:  pcre-devel
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
%if 0%{?with_passenger}
BuildRequires:  rubygem-passenger-devel-static
Recommends:     packageand(rubygem-passenger:rubygem-passenger-nginx)
%endif
PreReq:         %fillup_prereq
PreReq:         %insserv_prereq
PreReq:         pwdutils
Provides:       nginx = %{version}-%{release}
#
Conflicts:      nginx-0.5 nginx-0.6 nginx-0.7 nginx-0.8 nginx-0.9
%requires_eq    perl
#
Url:            http://nginx.org/
Source:         http://nginx.org/download/nginx-%{version}.tar.bz2
Source1:        nginx.init
# PATCH-FIX-UPSTREAM nginx-0.4.0-no_Werror.patch
Patch:          nginx-0.4.0-no_Werror.patch
# PATCH-FIX-UPSTREAM nginx-0.6.38-html.patch
Patch2:         nginx-1.0.12-html.patch
# PATCH-FIX-UPSTREAM nginx-0.4.0-perl_vendor_install.patch
Patch3:         nginx-0.4.0-perl_vendor_install.patch
# PATCH-FIX-UPSTREAM nginx-1.0.4_default_config.patch
Patch4:         nginx-1.0.4_default_config.patch
#
Summary:        A HTTP server and IMAP/POP3 proxy server
%description
nginx [engine x] is a HTTP server and IMAP/POP3 proxy server written by Igor Sysoev.
It has been running on many heavily loaded Russian sites for more than two years.

Author:
-------
    Igor Sysoev

%prep
%setup -n %{pkg_name}-%{version}
%patch
%patch3
%patch4
%patch2
perl -pi -e 's|\r\n|\n|g' contrib/geo2nginx.pl

%build
%if 0%{?with_passenger}
ln -s %{_libdir}/ruby/gems/%{rb_ver}/gems/passenger-* passenger
%endif
./configure                                    \
  --prefix=%{ngx_prefix}/                      \
  --sbin-path=%{ngx_sbindir}                   \
  --conf-path=%{ngx_conf_path}                 \
  --error-log-path=%{ngx_error_log}            \
  --http-log-path=%{ngx_access_log}            \
  --pid-path=%{ngx_pid_path}                   \
  --lock-path=%{ngx_lock_path}                 \
  --http-client-body-temp-path=%{ngx_tmp_http} \
  --http-proxy-temp-path=%{ngx_tmp_proxy}      \
  --http-fastcgi-temp-path=%{ngx_tmp_fcgi}     \
  --http-uwsgi-temp-path=%{ngx_tmp_uwsgi}      \
  --http-scgi-temp-path=%{ngx_tmp_scgi}        \
  --user=nginx --group=nginx                   \
  --with-rtsig_module                          \
  --with-select_module                         \
  --with-poll_module                           \
  --with-ipv6                                  \
%if  0%{?suse_version} > 1110
  --with-file-aio                              \
%endif
  --with-http_ssl_module                       \
  --with-http_realip_module                    \
  --with-http_addition_module                  \
  --with-http_xslt_module                      \
  --with-http_image_filter_module              \
  --with-http_geoip_module                     \
  --with-http_sub_module                       \
  --with-http_dav_module                       \
  --with-http_flv_module                       \
  --with-http_mp4_module                       \
  --with-http_gzip_static_module               \
  --with-http_random_index_module              \
  --with-http_secure_link_module               \
  --with-http_degradation_module               \
  --with-http_stub_status_module               \
  --with-http_perl_module                      \
  --with-perl=%{_bindir}/perl                  \
  --with-mail                                  \
  --with-mail_ssl_module                       \
  --with-pcre                                  \
  %if 0%{?with_libatomic}
  --with-libatomic                             \
  %endif
  %if 0%{?with_passenger}
  --add-module=passenger/ext/nginx             \
  %endif
  %if 0%{?with_google_perftools}
  --with-google_perftools_module               \
  %endif
  %if 0%{?with_cpp_test}
  --with-cpp_test_module                       \
  %endif
  --with-md5=/usr                              \
  --with-sha1=/usr                             \
%if 0%{?suse_version} > 1000 || 0%{?fedora_version} > 4 || 0%{?mandriva_version} > 2006
  --with-cc-opt="%{optflags} -fstack-protector"
%else
  --with-cc-opt="%{optflags}"
%endif
%{__make}

%install
%makeinstall
%perl_process_packlist
#
%{__install} -d -m 0750 %{buildroot}%{ngx_home}/{,tmp,proxy,fastcgi,scgi,uwsgi}
#
%{__install} -D -m 0755 %{S:1} %{buildroot}%{_sysconfdir}/init.d/%{pkg_name}
%{__ln_s} -f %{_sysconfdir}/init.d/%{pkg_name} %{buildroot}%{_sbindir}/rc%{pkg_name}
%{__rm} %{buildroot}/srv/www/htdocs/index.html

%post
%fillup_and_insserv %{pkg_name}

%preun
%stop_on_removal %{pkg_name}

%postun
%restart_on_update %{pkg_name}
%{insserv_cleanup}

%clean
%{__rm} -rf %{buildroot}

%pre
/usr/sbin/groupadd -r %{ngx_user_group} &>/dev/null ||:
/usr/sbin/useradd -g %{ngx_user_group} -s /bin/false -r -c "user for %{ngx_user_group}" -d %{ngx_home} %{ngx_user_group} &>/dev/null ||:

%files
%defattr(-,root,root,-)
%dir %{ngx_conf_dir}/
%config(noreplace) %{ngx_conf_dir}/koi-utf
%config(noreplace) %{ngx_conf_dir}/koi-win
%config(noreplace) %{ngx_conf_dir}/fastcgi_params
%config(noreplace) %{ngx_conf_dir}/fastcgi_params.default
%config(noreplace) %{ngx_conf_dir}/mime.types
%config(noreplace) %{ngx_conf_dir}/mime.types.default
%config(noreplace) %{ngx_conf_dir}/nginx.conf
%config(noreplace) %{ngx_conf_dir}/nginx.conf.default
%config(noreplace) %{ngx_conf_dir}/fastcgi.conf
%config(noreplace) %{ngx_conf_dir}/fastcgi.conf.default
%config(noreplace) %{ngx_conf_dir}/win-utf
%config(noreplace) %{ngx_conf_dir}/scgi_params
%config(noreplace) %{ngx_conf_dir}/scgi_params.default
%config(noreplace) %{ngx_conf_dir}/uwsgi_params
%config(noreplace) %{ngx_conf_dir}/uwsgi_params.default
%{perl_vendorarch}/auto/nginx/
%{perl_vendorarch}/nginx.pm
%{ngx_sbindir}
%{_mandir}/man3/nginx.3pm*
/srv/www/htdocs/50x.html
%if 0%{?suse_version} && 0%{?suse_version} < 1140
%{_localstatedir}/adm/perl-modules/%{name}
%endif
%{_sysconfdir}/init.d/%{pkg_name}
%{_sbindir}/rc%{pkg_name}
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) /var/log/nginx/
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_home}/
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_tmp_http}
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_tmp_proxy}
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_tmp_fcgi}
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_tmp_scgi}
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_tmp_uwsgi}
%doc CHANGES* LICENSE README
%doc conf/ contrib/

%changelog
* Sat May  5 2012 cs@linux-administrator.com
- upstream update 1.0.15
  * Security: specially crafted mp4 file might allow to overwrite memory
    locations in a worker process if the ngx_http_mp4_module was used,
    potentially resulting in arbitrary code execution (CVE-2012-2089).
  * Bugfix: in the ngx_http_mp4_module.
* Tue Mar 20 2012 cs@linux-administrator.com
- upstream update 1.0.14
  * Security: content of previously freed memory might be sent to a
    client if backend returned specially crafted response.
- additional changes from 1.0.13
  * Feature: the "return" and "error_page" directives can now be used to
    return 307 redirections.
  * Bugfix: a segmentation fault might occur in a worker process if the
    "resolver" directive was used and there was no "error_log" directive
    specified at global level.
  * Bugfix: memory leaks.
  * Bugfix: nginx might log incorrect error "upstream prematurely closed
    connection" instead of correct "upstream sent too big header" one.
  * Bugfix: on ZFS filesystem disk cache size might be calculated
    incorrectly; the bug had appeared in 1.0.1.
  * Bugfix: the number of internal redirects to named locations was not
    limited.
  * Bugfix: temporary files might be not removed if the "proxy_store"
    directive was used with SSI includes.
  * Bugfix: in some cases non-cacheable variables (such as the $args
    variable) returned old empty cached value.
  * Bugfix: the "proxy_redirect" directives might be inherited
    incorrectly.
  * Bugfix: nginx could not be built with the ngx_http_perl_module if the
  - -with-openssl option was used.
  * Bugfix: nginx could not be built by the icc 12.1 compiler.
* Sat Feb 18 2012 cs@linux-administrator.com
- upstream update 1.0.12
  * Feature: the "TLSv1.1" and "TLSv1.2" parameters of the
    "ssl_protocols" directive.
  * Feature: the "if" SSI command supports captures in regular
    expressions.
  * Bugfix: the "if" SSI command did not work inside the "block" command.
  * Bugfix: in AIO error handling on FreeBSD.
  * Bugfix: in the OpenSSL library initialization.
  * Bugfix: the "worker_cpu_affinity" directive might not work.
  * Bugfix: the "limit_conn_log_level" and "limit_req_log_level"
    directives might not work.
  * Bugfix: the "read_ahead" directive might not work combined with
    "try_files" and "open_file_cache".
  * Bugfix: the "proxy_cache_use_stale" directive with "error" parameter
    did not return answer from cache if there were no live upstreams.
  * Bugfix: a segmentation fault might occur in a worker process if small
    time was used in the "inactive" parameter of the "proxy_cache_path"
    directive.
  * Bugfix: responses from cache might hang.
  * Bugfix: in error handling while connecting to a backend.
    Thanks to Piotr Sikora.
  * Bugfix: in the "epoll" event method.
    Thanks to Yichun Zhang.
  * Bugfix: the $sent_http_cache_control variable might contain a wrong
    value if the "expires" directive was used.
    Thanks to Yichun Zhang.
  * Bugfix: the "limit_rate" directive did not allow to use full
    throughput, even if limit value was very high.
  * Bugfix: the "sendfile_max_chunk" directive did not work, if the
    "limit_rate" directive was used.
  * Bugfix: nginx could not be built on Solaris; the bug had appeared in
    1.0.11.
  * Bugfix: in the ngx_http_scgi_module.
  * Bugfix: in the ngx_http_mp4_module.
* Thu Jan 26 2012 cs@linux-administrator.com
- upstream update 1.0.11
  * Change: now double quotes are encoded in an "echo" SSI-command
    output.
  * Feature: the "image_filter_sharpen" directive.
  * Bugfix: a segmentation fault might occur in a worker process if SNI
    was used; the bug had appeared in 1.0.9.
  * Bugfix: SIGWINCH signal did not work after first binary upgrade; the
    bug had appeared in 1.0.9.
  * Bugfix: the "If-Modified-Since", "If-Range", etc. client request
    header lines might be passed to backend while caching; or not passed
    without caching if caching was enabled in another part of the
    configuration.
  * Bugfix: in the "scgi_param" directive, if complex parameters were
    used.
  * Bugfix: "add_header" and "expires" directives did not work if a
    request was proxied and response status code was 206.
  * Bugfix: in the "expires @time" directive.
  * Bugfix: in the ngx_http_flv_module.
  * Bugfix: in the ngx_http_mp4_module.
  * Bugfix: nginx could not be built on FreeBSD 10.
  * Bugfix: nginx could not be built on AIX.
* Mon Dec  5 2011 cs@linux-administrator.com
- upstream update 1.0.10
  * Bugfix: a segmentation fault might occur in a worker process if
    resolver got a big DNS response.
    Thanks to Ben Hawkes.
  * Bugfix: in cache key calculation if internal MD5 implementation was
    used; the bug had appeared in 1.0.4.
  * Bugfix: the module ngx_http_mp4_module sent incorrect
    "Content-Length" response header line if the "start" argument was
    used.
    Thanks to Piotr Sikora.
- additional changes from 1.0.9
  * Change: now the 0x7F-0x1F characters are escaped as \xXX in an
    access_log.
  * Change: now SIGWINCH signal works only in daemon mode.
  * Feature: "proxy/fastcgi/scgi/uwsgi_ignore_headers" directives support
    the following additional values: X-Accel-Limit-Rate,
    X-Accel-Buffering, X-Accel-Charset.
  * Feature: decrease of memory consumption if SSL is used.
  * Feature: accept filters are now supported on NetBSD.
  * Feature: the "uwsgi_buffering" and "scgi_buffering" directives.
    Thanks to Peter Smit.
  * Bugfix: a segmentation fault occurred on start or while
    reconfiguration if the "ssl" directive was used at http level and
    there was no "ssl_certificate" defined.
  * Bugfix: some UTF-8 characters were processed incorrectly.
    Thanks to Alexey Kuts.
  * Bugfix: the ngx_http_rewrite_module directives specified at "server"
    level were executed twice if no matching locations were defined.
  * Bugfix: a socket leak might occurred if "aio sendfile" was used.
  * Bugfix: connections with fast clients might be closed after
    send_timeout if file AIO was used.
  * Bugfix: in the ngx_http_autoindex_module.
  * Bugfix: the module ngx_http_mp4_module did not support seeking on
    32-bit platforms.
  * Bugfix: non-cacheable responses might be cached if
    "proxy_cache_bypass" directive was used.
    Thanks to John Ferlito.
  * Bugfix: cached responses with an empty body were returned
    incorrectly; the bug had appeared in 0.8.31.
  * Bugfix: 201 responses of the ngx_http_dav_module were incorrect; the
    bug had appeared in 0.8.32.
  * Bugfix: in the "return" directive.
  * Bugfix: the "ssl_verify_client", "ssl_verify_depth", and
    "ssl_prefer_server_ciphers" directives might work incorrectly if SNI
    was used.
* Sun Oct 16 2011 cs@linux-administrator.com
- upstream update 1.0.8
  * Bugfix: nginx could not be built --with-http_mp4_module and without
  - -with-debug option.
- additional changes from 1.0.7
  * Change: now if total size of all ranges is greater than source
    response size, then nginx disables ranges and returns just the source
    response.
  * Feature: the "max_ranges" directive.
  * Feature: the module ngx_http_mp4_module.
  * Feature: the "worker_aio_requests" directive.
  * Bugfix: if nginx was built --with-file-aio it could not be run on
    Linux kernel which did not support AIO.
  * Bugfix: in Linux AIO error processing.
    Thanks to Hagai Avrahami.
  * Bugfix: in Linux AIO combined with open_file_cache.
  * Bugfix: open_file_cache did not update file info on retest if file
    was not atomically changed.
  * Bugfix: reduced memory consumption for long-lived requests.
  * Bugfix: in the "proxy/fastcgi/scgi/uwsgi_ignore_client_abort"
    directives.
  * Bugfix: nginx could not be built on MacOSX 10.7.
  * Bugfix: in the "proxy/fastcgi/scgi/uwsgi_ignore_client_abort"
    directives.
  * Bugfix: request body might be processed incorrectly if client used
    pipelining.
  * Bugfix: in the "request_body_in_single_buf" directive.
  * Bugfix: in "proxy_set_body" and "proxy_pass_request_body" directives
    if SSL connection to backend was used.
  * Bugfix: nginx hogged CPU if all servers in an upstream were marked as
    "down".
  * Bugfix: a segmentation fault might occur during reconfiguration if
    ssl_session_cache was defined but not used in previous configuration.
  * Bugfix: a segmentation fault might occur in a worker process if many
    backup servers were used in an upstream.
- additional changes from 1.0.6
  * Feature: cache loader run time decrease.
  * Feature: loading time decrease of configuration with large number of
    HTTPS sites.
  * Feature: now nginx supports ECDHE key exchange ciphers.
    Thanks to Adrian Kotelba.
  * Feature: the "lingering_close" directive.
  * Feature: now shared zones and caches use POSIX semaphores on Solaris.
    Thanks to Den Ivanov.
  * Bugfix: nginx could not be built on Linux 3.0.
  * Bugfix: a segmentation fault might occur in a worker process if
    "fastcgi/scgi/uwsgi_param" directives were used with values starting
    with "HTTP_"; the bug had appeared in 0.8.40.
  * Bugfix: in closing connection for pipelined requests.
  * Bugfix: nginx did not disable gzipping if client sent "gzip;q=0" in
    "Accept-Encoding" request header line.
  * Bugfix: in timeout in unbuffered proxied mode.
  * Bugfix: memory leaks when a "proxy_pass" directive contains variables
    and proxies to an HTTPS backend.
  * Bugfix: in parameter validaiton of a "proxy_pass" directive with
    variables.
    Thanks to Lanshun Zhou.
  * Bugfix: SSL did not work on QNX.
  * Bugfix: SSL modules could not be built by gcc 4.6 without
  - -with-debug option.
- additional changes from 1.0.5
  * Change: now default SSL ciphers are "HIGH:!aNULL:!MD5".
    Thanks to Rob Stradling.
  * Feature: the "referer_hash_max_size" and "referer_hash_bucket_size"
    directives.
    Thanks to Witold Filipczyk.
  * Feature: $uid_reset variable.
  * Bugfix: a segmentation fault might occur in a worker process, if a
    caching was used.
    Thanks to Lanshun Zhou.
  * Bugfix: worker processes may got caught in an endless loop during
    reconfiguration, if a caching was used; the bug had appeared in
    0.8.48.
    Thanks to Maxim Dounin.
  * Bugfix: "stalled cache updating" alert.
    Thanks to Maxim Dounin.
* Thu Jun  9 2011 ammler@openttdcoop.org
- upstream update 1.0.4
  * Change: now regular expressions case sensitivity in the "map"
    directive is given by prefixes "~" or "~*".
  * Feature: now shared zones and caches use POSIX semaphores on
    Linux.  Thanks to Denis F. Latypoff.
  * Bugfix: "stalled" cache updating" alert.
  * Bugfix: nginx could not be built
  - -without-http_auth_basic_module; the bug had appeared in
    1.0.3.
- additional changes from 1.0.3
  - Feature: the "auth_basic_user_file" directive supports "$apr1",
    "{PLAIN}", and "{SSHA}" password encryption methods.  Thanks to
    Maxim Dounin.
  - Feature: the "geoip_org" directive and $geoip_org variable.
    Thanks to Alexander Uskov, Arnaud Granal, and Denis F.
    Latypoff.
  - Feature: ngx_http_geo_module and ngx_http_geoip_module support
    IPv4 addresses mapped to IPv6 addresses.
  - Bugfix: a segmentation fault occurred in a worker process
    during testing IPv4 address mapped to IPv6 address, if access
    or deny rules were defined only for IPv6; the bug had appeared
    in 0.8.22.
  - Bugfix: a cached response may be broken if proxy/fastcgi/scgi/
    uwsgi_cache_bypass and proxy/fastcgi/scgi/uwsgi_no_cache
    directive values were different; the bug had appeared in
    0.8.46.
- additional changes from 1.0.2
  - Feature: now shared zones and caches use POSIX semaphores.
  - Bugfix: in the "rotate" parameter of the "image_filter"
    directive.  Thanks to Adam Bocim.
  - Bugfix: nginx could not be built on Solaris; the bug had
    appeared in 1.0.1.
- additional changes from 1.0.1
  - Change: now the "split_clients" directive uses MurmurHash2
    algorithm because of better distribution.  Thanks to Oleg
    Mamontov.
  - Change: now long strings starting with zero are not considered
    as false values.  Thanks to Maxim Dounin.
  - Change: now nginx uses a default listen backlog value 511 on
    Linux.
  - Feature: the $upstream_... variables may be used in the SSI and
    perl modules.
  - Bugfix: now nginx limits better disk cache size.  Thanks to
    Oleg Mamontov.
  - Bugfix: a segmentation fault might occur while parsing
    incorrect IPv4 address; the bug had appeared in 0.9.3.  Thanks
    to Maxim Dounin.
  - Bugfix: nginx could not be built by gcc 4.6 without
  - -with-debug option.
  - Bugfix: nginx could not be built on Solaris 9 and earlier; the
    bug had appeared in 0.9.3.  Thanks to Dagobert Michelsen.
  - Bugfix: $request_time variable had invalid values if
    subrequests were used; the bug had appeared in 0.8.47.  Thanks
    to Igor A. Valcov.
- new config directories included in context http:
  conf.d/*.conf on top before first server
  vhosts.d/*.conf on bottom (for servers)
* Thu May 26 2011 mrueckert@suse.de
- more accurate license header: BSD-2-Clause
* Thu Apr 14 2011 mrueckert@suse.de
- move the libatomic usage to sle11/11.1 or newer
* Thu Apr 14 2011 mrueckert@suse.de
- remove /srv/www/htdocs/index.html (bnc#670031).
* Thu Apr 14 2011 mrueckert@suse.de
- build with libatomic_ops
* Thu Apr 14 2011 mrueckert@suse.de
- minor spec file cleanup
  - use perl instead of dos2unix
  - remove commented out patches from the preamble
  - fix ordering in preamble
* Wed Apr 13 2011 alexandre@exatati.com.br
- Add epoll in default events config as recommended in
  http://www.kegel.com/c10k.html#nb.epoll.
* Tue Apr 12 2011 mrueckert@suse.de
- enable building of the passenger extension
* Tue Apr 12 2011 mrueckert@suse.de
- added more directives to the configure line
  - specify tmp path for scgi/uwsgi
  - enabled more modules
  - geoip lookup
  - http_degradation
  - mail ssl support
  - added build time options to build the profiling/testing stuff
  - see with_google_perftools and with_cpp_test
* Tue Apr 12 2011 mrueckert@suse.de
- start 1.0 branch package
